@@ -33,13 +33,16 @@ class WeeklyRecurrence(object):
 
         weekday = WEEKDAYS[day]
         days_ahead = weekday - current_date_time.weekday()
-        if days_ahead <= 0:  # target day already happened this week
+        if days_ahead < 0:  # target day already happened this week
             days_ahead += 7
         return current_date_time + datetime.timedelta(days_ahead)
 
     def rrule(self):
         return {'freq': 'weekly'}
 
+    def __str__(self):
+        return "Weekly"
+
 
 class BiWeeklyRecurrence(object):
     """Meetings occuring on alternate weeks.
@@ -71,6 +74,9 @@ class BiWeeklyRecurrence(object):
     def rrule(self):
         return {'freq': 'weekly', 'interval': 2}
 
+    def __str__(self):
+        return "Every two weeks (on %s weeks)" % self.style
+
 
 supported_recurrences = {
     'weekly': WeeklyRecurrence(),
